.. _chapter_1_introduction:

Chapter 1: Introduction
=======================

In chapter 1, we introduce you to the **PyAutoFit** and describe how to set up your own model, fit it to data via
a non-linear search and inspect and interpret the results.

You can start the tutorials right now by going to `our binder <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/HEAD>`_
and navigating to the folder ``notebooks/howtofit/chapter_1_introduction``. They are also on the `autofit_workspace <https://github.com/Jammy2211/autofit_workspace>`_.

The chapter contains the following tutorials:

`Tutorial 1: Models <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_1_introduction/tutorial_1_models.ipynb>`_
- Composing a model in **PyAutoFit**.

`Tutorial 2: Fitting Data <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_1_introduction/tutorial_2_fitting_data.ipynb>`_
- Fitting a model with an input set of parameters to data.

`Tutorial 3: Non Linear Search <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_1_introduction/tutorial_3_non_linear_search.ipynb>`_
- The Concepts of a non-linear search, parameter space and priors.

`Tutorial 4: Complex Models <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_1_introduction/tutorial_4_complex_models.ipynb>`_
- Composing and fitting complex models.

`Tutorial 5: Results and Samples <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/release?filepath=notebooks/howtofit/chapter_1_introduction/tutorial_5_results_and_samples.ipynb>`_
- The results of a model-fit output by **PyAutoFit**.
